/*
		TestApp.m


		This class is just for testing the sprite engine.
		
		Created by Ian Howle on 2/19/2005.
		Public Domain.
*/




#import "TestApp.h"



@implementation TestApp



- (void)awakeFromNib
{
	GameSprite		*ship1 = [[GameSprite alloc] initWithIndentifier:@"ship1"];
	GameSprite		*ship2 = [[GameSprite alloc] initWithIndentifier:@"ship2"];
	GameSprite		*ship3 = [[GameSprite alloc] initWithIndentifier:@"ship3"];



	NSImage		*shipImage = [NSImage imageNamed:@"ship"];
	NSArray		*frames = [[NSArray alloc] initWithObjects:[NSValue valueWithRect:NSMakeRect( 0.0, 0.0, [shipImage size].width, [shipImage size].height )], nil];
	
	[ship1 setupSpriteWithMasterImage:shipImage withFrames:frames atPos:NSMakePoint( 350.0, 200.0 ) inDir:NSMakePoint( 5.0, -3.0 ) withOpacity:1.0];
	[ship2 setupSpriteWithMasterImage:shipImage withFrames:frames atPos:NSMakePoint( 200.0, 200.0 ) inDir:NSMakePoint( 3.0, 3.0 ) withOpacity:1.0];
	[ship3 setupSpriteWithMasterImage:shipImage withFrames:frames atPos:NSMakePoint( 100.0, 300.0 ) inDir:NSMakePoint( 2.0, -1.0 ) withOpacity:1.0];

	[frames release];

	
	[ship1 setBoundaryRect:[MyViewObj bounds] autoConfineToBoundary:YES];
	[ship2 setBoundaryRect:[MyViewObj bounds] autoConfineToBoundary:YES];
	[ship3 setBoundaryRect:[MyViewObj bounds] autoConfineToBoundary:YES];
	
	[ship2 setShadowOffset:NSMakeSize( 10.0, 10.0 ) color:[NSColor redColor] blur:10.0];
	

	[MyViewObj addSprite:ship1];	// Add ship1 to the sprite controller.
	[MyViewObj addSprite:ship2];	// Add ship2 to the sprite controller.
	[MyViewObj addSprite:ship3];	// Add ship3 to the sprite controller.


	[ship2 setSpinRate:0.01 degreesPerRotation:-5.0];

	[ship3 release];
	[ship2 release];
	[ship1 release];
	

	[MyViewObj startSprites];
}





- (void)dealloc
{
	[MyViewObj release];

	[super dealloc];
}





/*****
		startStopSprites:
		
		This method starts and stops all sprite action.
*****/

- (IBAction)startStopSprites:(id)sender
{
	if ( [MyViewObj areSpritesActive] )
	{
		[MyViewObj stopSprites];
		
		[sender setTitle:@"Start Sprites"];
	}
	else
	{
		[MyViewObj startSprites];
		
		[sender setTitle:@"Stop Sprites"];
	}
}





/*****
		visibility:
		
		This method makes a sprite visible or invisible.
*****/

- (IBAction)visibility:(id)sender
{
	GameSprite		*theSprite = [MyViewObj spriteRef:@"ship2"];
	
	
	if ( [theSprite isVisible] )
	{
		[theSprite setVisible:NO];
		
		[sender setTitle:@"Visible"];
	}
	else
	{
		[theSprite setVisible:YES];
		
		[sender setTitle:@"Invisible"];
	}
}





/*****
		fading:
		
		This method fades the sprite completely in or out.
*****/

- (IBAction)fading:(id)sender
{
	GameSprite		*theSprite = [MyViewObj spriteRef:@"ship1"];
	
	
	if ( [[sender title] isEqualToString:@"Fade Out"] )
	{
		[theSprite fadeTo:0.0 atRate:0.1];
		
		[sender setTitle:@"Fade In"];
	}
	else
	{
		[theSprite fadeTo:1.0 atRate:0.1];
		
		[sender setTitle:@"Fade Out"];
	}
}





/*****
		opacityLevel:
		
		This method changes a sprite's opacity level.
*****/

- (IBAction)opacityLevel:(id)sender
{
	[[MyViewObj spriteRef:@"ship3"] setOpacity:[sender floatValue]];
}





/*****
		strobeRate:
		
		This method changes a sprite's strobe rate.
*****/

- (IBAction)strobeRate:(id)sender
{
	[[MyViewObj spriteRef:@"ship1"] strobeAtRate:[sender floatValue]];
}





/*****
		shear:
		
		This method shears the sprite's vertically and horizontally.
*****/

- (IBAction)shear:(id)sender
{
	[[MyViewObj spriteRef:@"ship1"] shearXBy:[[sender cellWithTag:0] floatValue] yBy:[[sender cellWithTag:1] floatValue]];
}





/*****
		scaleByDimensions:
		
		This method scales the sprites dimensions (width and height) based on the
		slider value.
*****/

- (IBAction)scaleByDimensions:(id)sender
{
	[[MyViewObj spriteRef:@"ship1"] newWidth:[[sender cellWithTag:0] floatValue] newHeight:[[sender cellWithTag:1] floatValue] center:NO];
}





/*****
		scaleByPercentage:
		
		This method scales the sprite based on the slider's percentage value.
*****/

- (IBAction)scaleByPercentage:(id)sender
{
	[[MyViewObj spriteRef:@"ship1"] scaleByPercent:[sender floatValue] center:YES];
}





/*****
		collisionDetection:
		
		This method toggles collision detection on/off.
*****/

- (IBAction)collisionDetection:(id)sender
{
	if ( [sender state] == NSOnState )
	{
		[MyViewObj setSpriteCollision:YES];
	}
	else
	{
		[MyViewObj setSpriteCollision:NO];
	}
}





- (IBAction)shrinkExpand:(id)sender
{
	if ( [[sender title] isEqualToString:@"shrink"] )
	{
		[[MyViewObj spriteRef:@"ship1"] scaleToOriginalSizeByPixelInc:2.0 atRate:0.1 center:YES];
		[sender setTitle:@"expand"];
	}
	else
	{
		[[MyViewObj spriteRef:@"ship1"] scaleToPercentage:300.0 byPixelInc:2.0 atRate:0.1 center:YES];
		[sender setTitle:@"shrink"];
	}
	
	[MyViewObj setNeedsDisplay:YES];
}





- (IBAction)setShadowOffset:(id)sender
{
	int				sliderTag = [sender tag];
	NSShadow		*aShadow = [[MyViewObj spriteRef:@"ship2"] shadow];
	NSSize			shadowOffset = [aShadow shadowOffset];
	
	
	if ( sliderTag == 1 )
	{
		shadowOffset.height = [sender floatValue];
	}
	else
	{
		shadowOffset.width = [sender floatValue];
	}
	
	
	[aShadow setShadowOffset:shadowOffset];
}





- (IBAction)setBlur:(id)sender
{
	NSShadow		*aShadow = [[MyViewObj spriteRef:@"ship2"] shadow];
	
	[aShadow setShadowBlurRadius:[sender floatValue]];
}



@end
